# Examples

To ensure data is present on all examples, please run [seed.py](seed.py) **first**

## Example 1

A simple SELECT Statement

## Example 2

A SELECT statement with subqueries and column aliases

## Example 3

An UPDATE statement
